# LaoNLP
<a href="https://www.buymeacoffee.com/wannaphong"><img src="https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png" alt="Buy Me A Coffee" style="height: 41px !important;width: 174px !important;box-shadow: 0px 3px 2px 0px rgba(190, 190, 190, 0.5) !important;-webkit-box-shadow: 0px 3px 2px 0px rgba(190, 190, 190, 0.5) !important;" ></a>
[![Downloads](https://pepy.tech/badge/laonlp)](https://pepy.tech/project/laonlp)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.6833407.svg)](https://doi.org/10.5281/zenodo.6833407)

Lao language Natural Language Processing (NLP)

## Features

- Word tokenizer
- Sentence tokenizer
- Part-of-speech
- Lao to Thai script
- Thai to Lao script
- Word dictionary
- Word Vector (**New**)

## Install
```
pip install laonlp
```

Documentation: https://github.com/wannaphong/LaoNLP/wiki

## Citations

If you use `LaoNLP` in your project or publication, please cite the library as follows

```
Wannaphong Phatthiyaphaibun. (2022). LaoNLP: Lao language Natural Language Processing. Zenodo. https://doi.org/10.5281/zenodo.6833407
```

or BibTeX entry:

``` bib
@misc{wannaphong_phatthiyaphaibun_2022_6833407,
  author       = {Wannaphong Phatthiyaphaibun},
  title        = {LaoNLP: Lao language Natural Language Processing},
  month        = jul,
  year         = 2022,
  publisher    = {Zenodo},
  doi          = {10.5281/zenodo.6833407},
  url          = {https://doi.org/10.5281/zenodo.6833407}
}
```

## License

```
   Copyright 2020 - 2022 Wannaphong Phatthiyaphaibun

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 ```
